from ...common import (WEAKNESS_BEFORE_STOP_WORDS, WEAKNESS_PATTERN, CONFIGURATION_PATTERN, IMPACT_PATTERN,
                       IMPACT_BEFORE_STOP_WORDS, CONDITION_BEFORE_STOP_WORDS, CONDITION_PATTERN)

CONFIG_WEAKNESS_CONDITION_PATTERN = (CONFIGURATION_PATTERN + WEAKNESS_BEFORE_STOP_WORDS + WEAKNESS_PATTERN +
                                     CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN)


# configuration weakness condition impact
DETAILS_4_1 = CONFIG_WEAKNESS_CONDITION_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + r'\.$'


CONFIG_WEAKNESS_CONDITION_PATTERNS = {
    '4_1': DETAILS_4_1,
}
