from ...common import (CONFIGURATION_PATTERN, ROOT_CAUSE_PATTERN, ROOT_CAUSE_BEFORE_STOP_WORD,
                       CONDITION_BEFORE_STOP_WORDS, CONDITION_PATTERN, IMPACT_BEFORE_STOP_WORDS, IMPACT_PATTERN)


# configuration root_cause condition
CONFIG_CAUSE_CONDITION_PATTERN = (r'(?:The |)' + CONFIGURATION_PATTERN + ROOT_CAUSE_BEFORE_STOP_WORD +
                                 ROOT_CAUSE_PATTERN + CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN)


# configuration root_cause condition impact
DETAILS_4_1 = CONFIG_CAUSE_CONDITION_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + r'\.$'


CONFIG_CAUSE_CONDITION_PATTERNS = {
    '4_1': DETAILS_4_1
}
